# SVN Checkout

A python package to checkout SVN reposity based on project selected

##
 following query on terminal will checkout repos mention in the yaml.db file.
 
 ...
 python python fetch_Lib_SVN.py	-y db.yaml -p (Project Name) --user TandS

 ...